@@ -102,6 +102,16 @@ def load_yaml(file_name, check_if_exists = False, encoding = 'utf8'):
     return {'return':0,
             'meta': meta}
 
+
+###########################################################################
+def load_txt(file_name, encoding = 'utf8'):
+
+    with open(file_name, 'rt', encoding = encoding) as tf:
+        s = tf.read()
+
+    return {'return':0,
+            'string': s}
+
 ###########################################################################
 def save_yaml(file_name, meta={}, sort_keys=True, encoding = 'utf8'):
 
@@ -340,7 +350,7 @@ def parse_cm_object(obj, max_length = 2):
         (error) (str): error string if return>0
 
         cm_object (list): first argument: CM alias | UID
-                          (second element: 
+                          (second element: CM repo | UID)
 
     """
 
@@ -465,43 +475,6 @@ def get_list_from_cli(i, key):
 
     return tags
 
-###########################################################################
-def init_module(CModule, cmind, module_name):
-    """
-    Initialize module
-
-    Args:    
-
-    Returns:
-        return (int): return code == 0 if no error 
-                                  >0 if error
-
-        (error) (str): error string if return>0
-
-    """
-    
-
-    module = CModule(cmind, module_name)
-
-    module_path = module.path
-
-    # Try to load meta description
-    path_module_meta = os.path.join(os.path.dirname(module_path), cmind.cfg['file_cmeta'])
-
-    r = is_file_json_or_yaml(file_name = path_module_meta)
-    if r['return']>0: return r
-
-    module.meta = {}
-
-    if r['is_file']:
-        # Load artifact class
-        r=load_yaml_and_json(path_module_meta)
-        if r['return']>0: return r
-
-        module.meta = r['meta']
-
-    return {'return':0, 'module':module}
-
 ##############################################################################
 def merge_dicts(i):
     """Merge intelligently dict1 with dict2 key by key in contrast with dict1.update(dict2)
@@ -598,8 +571,7 @@ def process_meta_for_inheritance(i):
         r = cmind.access({'automation':automation,
                           'action':'search',
                           'artifact':artifact,
-                          'ignore_inheritance':True,
-                          'skip_con':True})
+                          'ignore_inheritance':True})
         if r['return']>0: return r
 
         lst = r['list']
@@ -625,3 +597,50 @@ def process_meta_for_inheritance(i):
         current_meta = base_meta
 
     return {'return':0, 'meta':current_meta}
+
+
+###########################################################################
+def find_api(file_name, func):
+    """Find func API in filename
+
+    Args:
+              file_name (str): Python module
+              fund (str): func name
+
+    Returns:
+              (dict): Unified CK dictionary:
+
+                return (int): return code =  0, if successful
+                                          >  0, if error
+                (error) (str): error text if return > 0
+
+                api (str): API string
+
+    """
+
+    # Load file
+    r = load_txt(file_name)
+    if r['return'] >0: return r
+
+    string = r['string']
+
+    api = ''
+    
+    # Search for def
+    j = string.find('def '+func+'(')
+    if j<0:
+        return {'return':1, 'error':'API not found'}
+
+    line1 = string.rfind('\n', 0, j)
+
+    line_comment1 = string.find('"""', j)
+    if line_comment1 <0 :
+        return {'return':1, 'error':'API not found'}
+
+    line_comment2 = string.find('"""', line_comment1 + 2)
+    if line_comment2 <0 :
+        return {'return':1, 'error':'API not found'}
+
+    api = string[line1+1:line_comment2+3]
+    
+    return {'return':0, 'api':api}
